@@ -12,10 +12,10 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 #ifdef RCSID
-static char RcsId[] = "@(#)$Revision: 5648 $";
+static char RcsId[] = "@(#)$Revision: 5738 $";
 #endif
 
-/* $Id: hextelt.c 5648 2011-06-09 05:18:42Z bmribler $ */
+/* $Id: hextelt.c 5738 2012-01-06 16:25:30Z bmribler $ */
 
 /*LINTLIBRARY */
 /* ------------------------------ hextelt.c -------------------------------
@@ -1021,6 +1021,8 @@ HXPinfo(accrec_t * access_rec, sp_info_block_t * info_block)
     info_block->key = SPECIAL_EXT;
 
     info_block->offset = info->extern_offset;
+    info_block->length = info->length;
+    info_block->length_file_name = info->length_file_name;
     info_block->path = info->extern_file_name;
 
 done:
