@@ -11,7 +11,7 @@
  * access to either file, you may request a copy from help@hdfgroup.org.     *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hproto.h 5648 2011-06-09 05:18:42Z bmribler $ */
+/* $Id: hproto.h 5830 2012-07-19 09:08:48Z bmribler $ */
 
 #ifndef _H_PROTO
 #define _H_PROTO
@@ -381,7 +381,7 @@ HDFLIBAPI intn Hdeldd(int32 file_id,      /* IN: File ID the tag/refs are in */
                 (void * dest, const void * src, uint32 item_size, uint32 num_items);
 
     HDFLIBAPI char *HIstrncpy
-                (char * dest, const char * source, int32 len);
+                (char * dest, const char * source, intn len);
 
     HDFLIBAPI int32 HDspaceleft
                 (void);
@@ -439,7 +439,7 @@ HDFLIBAPI intn Hdeldd(int32 file_id,      /* IN: File ID the tag/refs are in */
     HDFLIBAPI intn HLgetblockinfo
                 (int32 aid, int32* block_size, int32* num_blocks);
 
-    HDFLIBAPI int32 HLgetdatainfo
+    HDFLIBAPI intn HLgetdatainfo
 		(int32 file_id, uint8 *buf, uintn start_block,
 		 uintn info_count, int32 *offsetarray, int32 *lengtharray);
 
@@ -1383,6 +1383,8 @@ HDFLIBAPI intn GRgetattr(int32 id,int32 idx,void * data);
 
 HDFLIBAPI int32 GRfindattr(int32 id,const char *name);
 
+HDFLIBAPI intn GRgetcomptype (int32 riid, comp_coder_t *comp_type);
+
 HDFLIBAPI intn GRPshutdown(void);
 
 /* This function was added for hmap project only.  Feb-25-2011 */
@@ -1992,7 +1994,10 @@ HDFLIBAPI int  Hmpget(int *pagesize, /*OUT: pagesize to used in last open/create
     HDFLIBAPI int32 Vdelete
                 (int32 f, int32 ref);
 
-    HDFLIBAPI intn Visinternal
+    HDFLIBAPI intn Vgisinternal
+		(int32 vkey);
+
+    HDFLIBAPI intn Visinternal	/* this function is replaced by Vgisinternal */
 		(const char *classname);
 
     HDFLIBAPI intn Vgetvgroups
@@ -2114,6 +2119,10 @@ Vdeletetagref(int32 vkey, /* IN: vgroup key */
     HDFLIBAPI intn VSgetexternalfile
 		 (int32 vkey, uintn name_len, char *filename, int32* offset);
 
+    HDFLIBAPI intn VSgetexternalinfo
+		 (int32 vkey, uintn name_len, char *filename, int32* offset,
+		 int32* length);
+
     HDFLIBAPI intn VSfpack
                 (int32 vsid, intn packtype, const char *fields_in_buf,
                 void * buf, intn bufsz, intn n_records, 
